@@ -9,7 +9,7 @@ use Perl::Tidy;
 use Data::Dumper;
 use Module::Starter;
 $Data::Dumper::Deparse = 1;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 our %CLASS;
 our $SUB_INDEX = 1;
 
@@ -236,7 +236,7 @@ sub _make_path {
 		$path .= "/$_";
 		$path =~ m/(.*)/;
 		if (! -d $1) {
-			mkdir $1  or Carp::croak(qq/Cannot open file for writing $!/);
+			mkdir $1 or die "Cannot open file for writing $!";
 		}
 	}
 	return $path;
@@ -465,7 +465,7 @@ Module::Generate - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
